@@ -16,8 +16,8 @@ from cryptography.hazmat.primitives import constant_time, serialization
 from cryptography.hazmat.primitives.asymmetric.ec import EllipticCurvePublicKey
 from cryptography.hazmat.primitives.asymmetric.rsa import RSAPublicKey
 from cryptography.hazmat.primitives.asymmetric.types import (
+    CERTIFICATE_ISSUER_PUBLIC_KEY_TYPES,
     CERTIFICATE_PUBLIC_KEY_TYPES,
-    PUBLIC_KEY_TYPES,
 )
 from cryptography.x509.certificate_transparency import (
     SignedCertificateTimestamp,
@@ -41,7 +41,9 @@ from cryptography.x509.oid import (
     ObjectIdentifier,
 )
 
-ExtensionTypeVar = typing.TypeVar("ExtensionTypeVar", bound="ExtensionType")
+ExtensionTypeVar = typing.TypeVar(
+    "ExtensionTypeVar", bound="ExtensionType", covariant=True
+)
 
 
 def _key_identifier_from_public_key(
@@ -107,7 +109,7 @@ class ExtensionType(metaclass=abc.ABCMeta):
         )
 
 
-class Extensions(object):
+class Extensions:
     def __init__(
         self, extensions: typing.Iterable["Extension[ExtensionType]"]
     ) -> None:
@@ -155,15 +157,12 @@ class CRLNumber(ExtensionType):
 
         self._crl_number = crl_number
 
-    def __eq__(self, other: typing.Any) -> bool:
+    def __eq__(self, other: object) -> bool:
         if not isinstance(other, CRLNumber):
             return NotImplemented
 
         return self.crl_number == other.crl_number
 
-    def __ne__(self, other: typing.Any) -> bool:
-        return not self == other
-
     def __hash__(self) -> int:
         return hash(self.crl_number)
 
@@ -214,14 +213,14 @@ class AuthorityKeyIdentifier(ExtensionType):
         self._authority_cert_issuer = authority_cert_issuer
         self._authority_cert_serial_number = authority_cert_serial_number
 
-    # This takes PUBLIC_KEY_TYPES and not CERTIFICATE_PUBLIC_KEY_TYPES
-    # because an issuer cannot have an X25519/X448 key. This introduces
-    # some unfortunate asymmetry that requires typing users to explicitly
+    # This takes a subset of CERTIFICATE_PUBLIC_KEY_TYPES because an issuer
+    # cannot have an X25519/X448 key. This introduces some unfortunate
+    # asymmetry that requires typing users to explicitly
     # narrow their type, but we should make this accurate and not just
     # convenient.
     @classmethod
     def from_issuer_public_key(
-        cls, public_key: PUBLIC_KEY_TYPES
+        cls, public_key: CERTIFICATE_ISSUER_PUBLIC_KEY_TYPES
     ) -> "AuthorityKeyIdentifier":
         digest = _key_identifier_from_public_key(public_key)
         return cls(
@@ -248,7 +247,7 @@ class AuthorityKeyIdentifier(ExtensionType):
             ")>".format(self)
         )
 
-    def __eq__(self, other: typing.Any) -> bool:
+    def __eq__(self, other: object) -> bool:
         if not isinstance(other, AuthorityKeyIdentifier):
             return NotImplemented
 
@@ -259,9 +258,6 @@ class AuthorityKeyIdentifier(ExtensionType):
             == other.authority_cert_serial_number
         )
 
-    def __ne__(self, other: typing.Any) -> bool:
-        return not self == other
-
     def __hash__(self) -> int:
         if self.authority_cert_issuer is None:
             aci = None
@@ -312,15 +308,12 @@ class SubjectKeyIdentifier(ExtensionType):
     def __repr__(self) -> str:
         return "<SubjectKeyIdentifier(digest={0!r})>".format(self.digest)
 
-    def __eq__(self, other: typing.Any) -> bool:
+    def __eq__(self, other: object) -> bool:
         if not isinstance(other, SubjectKeyIdentifier):
             return NotImplemented
 
         return constant_time.bytes_eq(self.digest, other.digest)
 
-    def __ne__(self, other: typing.Any) -> bool:
-        return not self == other
-
     def __hash__(self) -> int:
         return hash(self.digest)
 
@@ -348,15 +341,12 @@ class AuthorityInformationAccess(ExtensionType):
     def __repr__(self) -> str:
         return "<AuthorityInformationAccess({})>".format(self._descriptions)
 
-    def __eq__(self, other: typing.Any) -> bool:
+    def __eq__(self, other: object) -> bool:
         if not isinstance(other, AuthorityInformationAccess):
             return NotImplemented
 
         return self._descriptions == other._descriptions
 
-    def __ne__(self, other: typing.Any) -> bool:
-        return not self == other
-
     def __hash__(self) -> int:
         return hash(tuple(self._descriptions))
 
@@ -384,15 +374,12 @@ class SubjectInformationAccess(ExtensionType):
     def __repr__(self) -> str:
         return "<SubjectInformationAccess({})>".format(self._descriptions)
 
-    def __eq__(self, other: typing.Any) -> bool:
+    def __eq__(self, other: object) -> bool:
         if not isinstance(other, SubjectInformationAccess):
             return NotImplemented
 
         return self._descriptions == other._descriptions
 
-    def __ne__(self, other: typing.Any) -> bool:
-        return not self == other
-
     def __hash__(self) -> int:
         return hash(tuple(self._descriptions))
 
@@ -400,7 +387,7 @@ class SubjectInformationAccess(ExtensionType):
         return rust_x509.encode_extension_value(self)
 
 
-class AccessDescription(object):
+class AccessDescription:
     def __init__(
         self, access_method: ObjectIdentifier, access_location: GeneralName
     ) -> None:
@@ -419,7 +406,7 @@ class AccessDescription(object):
             "on={0.access_location})>".format(self)
         )
 
-    def __eq__(self, other: typing.Any) -> bool:
+    def __eq__(self, other: object) -> bool:
         if not isinstance(other, AccessDescription):
             return NotImplemented
 
@@ -428,9 +415,6 @@ class AccessDescription(object):
             and self.access_location == other.access_location
         )
 
-    def __ne__(self, other: typing.Any) -> bool:
-        return not self == other
-
     def __hash__(self) -> int:
         return hash((self.access_method, self.access_location))
 
@@ -476,15 +460,12 @@ class BasicConstraints(ExtensionType):
             "<BasicConstraints(ca={0.ca}, " "path_length={0.path_length})>"
         ).format(self)
 
-    def __eq__(self, other: typing.Any) -> bool:
+    def __eq__(self, other: object) -> bool:
         if not isinstance(other, BasicConstraints):
             return NotImplemented
 
         return self.ca == other.ca and self.path_length == other.path_length
 
-    def __ne__(self, other: typing.Any) -> bool:
-        return not self == other
-
     def __hash__(self) -> int:
         return hash((self.ca, self.path_length))
 
@@ -505,15 +486,12 @@ class DeltaCRLIndicator(ExtensionType):
     def crl_number(self) -> int:
         return self._crl_number
 
-    def __eq__(self, other: typing.Any) -> bool:
+    def __eq__(self, other: object) -> bool:
         if not isinstance(other, DeltaCRLIndicator):
             return NotImplemented
 
         return self.crl_number == other.crl_number
 
-    def __ne__(self, other: typing.Any) -> bool:
-        return not self == other
-
     def __hash__(self) -> int:
         return hash(self.crl_number)
 
@@ -548,15 +526,12 @@ class CRLDistributionPoints(ExtensionType):
     def __repr__(self) -> str:
         return "<CRLDistributionPoints({})>".format(self._distribution_points)
 
-    def __eq__(self, other: typing.Any) -> bool:
+    def __eq__(self, other: object) -> bool:
         if not isinstance(other, CRLDistributionPoints):
             return NotImplemented
 
         return self._distribution_points == other._distribution_points
 
-    def __ne__(self, other: typing.Any) -> bool:
-        return not self == other
-
     def __hash__(self) -> int:
         return hash(tuple(self._distribution_points))
 
@@ -588,15 +563,12 @@ class FreshestCRL(ExtensionType):
     def __repr__(self) -> str:
         return "<FreshestCRL({})>".format(self._distribution_points)
 
-    def __eq__(self, other: typing.Any) -> bool:
+    def __eq__(self, other: object) -> bool:
         if not isinstance(other, FreshestCRL):
             return NotImplemented
 
         return self._distribution_points == other._distribution_points
 
-    def __ne__(self, other: typing.Any) -> bool:
-        return not self == other
-
     def __hash__(self) -> int:
         return hash(tuple(self._distribution_points))
 
@@ -604,7 +576,7 @@ class FreshestCRL(ExtensionType):
         return rust_x509.encode_extension_value(self)
 
 
-class DistributionPoint(object):
+class DistributionPoint:
     def __init__(
         self,
         full_name: typing.Optional[typing.Iterable[GeneralName]],
@@ -671,7 +643,7 @@ class DistributionPoint(object):
             "crl_issuer={0.crl_issuer})>".format(self)
         )
 
-    def __eq__(self, other: typing.Any) -> bool:
+    def __eq__(self, other: object) -> bool:
         if not isinstance(other, DistributionPoint):
             return NotImplemented
 
@@ -682,9 +654,6 @@ class DistributionPoint(object):
             and self.crl_issuer == other.crl_issuer
         )
 
-    def __ne__(self, other: typing.Any) -> bool:
-        return not self == other
-
     def __hash__(self) -> int:
         if self.full_name is not None:
             fn: typing.Optional[typing.Tuple[GeneralName, ...]] = tuple(
@@ -755,6 +724,17 @@ _REASON_BIT_MAPPING = {
     8: ReasonFlags.aa_compromise,
 }
 
+_CRLREASONFLAGS = {
+    ReasonFlags.key_compromise: 1,
+    ReasonFlags.ca_compromise: 2,
+    ReasonFlags.affiliation_changed: 3,
+    ReasonFlags.superseded: 4,
+    ReasonFlags.cessation_of_operation: 5,
+    ReasonFlags.certificate_hold: 6,
+    ReasonFlags.privilege_withdrawn: 7,
+    ReasonFlags.aa_compromise: 8,
+}
+
 
 class PolicyConstraints(ExtensionType):
     oid = ExtensionOID.POLICY_CONSTRAINTS
@@ -795,7 +775,7 @@ class PolicyConstraints(ExtensionType):
             "mapping})>".format(self)
         )
 
-    def __eq__(self, other: typing.Any) -> bool:
+    def __eq__(self, other: object) -> bool:
         if not isinstance(other, PolicyConstraints):
             return NotImplemented
 
@@ -804,9 +784,6 @@ class PolicyConstraints(ExtensionType):
             and self.inhibit_policy_mapping == other.inhibit_policy_mapping
         )
 
-    def __ne__(self, other: typing.Any) -> bool:
-        return not self == other
-
     def __hash__(self) -> int:
         return hash(
             (self.require_explicit_policy, self.inhibit_policy_mapping)
@@ -842,15 +819,12 @@ class CertificatePolicies(ExtensionType):
     def __repr__(self) -> str:
         return "<CertificatePolicies({})>".format(self._policies)
 
-    def __eq__(self, other: typing.Any) -> bool:
+    def __eq__(self, other: object) -> bool:
         if not isinstance(other, CertificatePolicies):
             return NotImplemented
 
         return self._policies == other._policies
 
-    def __ne__(self, other: typing.Any) -> bool:
-        return not self == other
-
     def __hash__(self) -> int:
         return hash(tuple(self._policies))
 
@@ -858,7 +832,7 @@ class CertificatePolicies(ExtensionType):
         return rust_x509.encode_extension_value(self)
 
 
-class PolicyInformation(object):
+class PolicyInformation:
     def __init__(
         self,
         policy_identifier: ObjectIdentifier,
@@ -889,7 +863,7 @@ class PolicyInformation(object):
             "y_qualifiers={0.policy_qualifiers})>".format(self)
         )
 
-    def __eq__(self, other: typing.Any) -> bool:
+    def __eq__(self, other: object) -> bool:
         if not isinstance(other, PolicyInformation):
             return NotImplemented
 
@@ -898,9 +872,6 @@ class PolicyInformation(object):
             and self.policy_qualifiers == other.policy_qualifiers
         )
 
-    def __ne__(self, other: typing.Any) -> bool:
-        return not self == other
-
     def __hash__(self) -> int:
         if self.policy_qualifiers is not None:
             pq: typing.Optional[
@@ -922,7 +893,7 @@ class PolicyInformation(object):
         return self._policy_qualifiers
 
 
-class UserNotice(object):
+class UserNotice:
     def __init__(
         self,
         notice_reference: typing.Optional["NoticeReference"],
@@ -944,7 +915,7 @@ class UserNotice(object):
             "{0.explicit_text!r})>".format(self)
         )
 
-    def __eq__(self, other: typing.Any) -> bool:
+    def __eq__(self, other: object) -> bool:
         if not isinstance(other, UserNotice):
             return NotImplemented
 
@@ -953,9 +924,6 @@ class UserNotice(object):
             and self.explicit_text == other.explicit_text
         )
 
-    def __ne__(self, other: typing.Any) -> bool:
-        return not self == other
-
     def __hash__(self) -> int:
         return hash((self.notice_reference, self.explicit_text))
 
@@ -968,7 +936,7 @@ class UserNotice(object):
         return self._explicit_text
 
 
-class NoticeReference(object):
+class NoticeReference:
     def __init__(
         self,
         organization: typing.Optional[str],
@@ -987,7 +955,7 @@ class NoticeReference(object):
             "{0.notice_numbers})>".format(self)
         )
 
-    def __eq__(self, other: typing.Any) -> bool:
+    def __eq__(self, other: object) -> bool:
         if not isinstance(other, NoticeReference):
             return NotImplemented
 
@@ -996,9 +964,6 @@ class NoticeReference(object):
             and self.notice_numbers == other.notice_numbers
         )
 
-    def __ne__(self, other: typing.Any) -> bool:
-        return not self == other
-
     def __hash__(self) -> int:
         return hash((self.organization, tuple(self.notice_numbers)))
 
@@ -1028,15 +993,12 @@ class ExtendedKeyUsage(ExtensionType):
     def __repr__(self) -> str:
         return "<ExtendedKeyUsage({})>".format(self._usages)
 
-    def __eq__(self, other: typing.Any) -> bool:
+    def __eq__(self, other: object) -> bool:
         if not isinstance(other, ExtendedKeyUsage):
             return NotImplemented
 
         return self._usages == other._usages
 
-    def __ne__(self, other: typing.Any) -> bool:
-        return not self == other
-
     def __hash__(self) -> int:
         return hash(tuple(self._usages))
 
@@ -1047,15 +1009,12 @@ class ExtendedKeyUsage(ExtensionType):
 class OCSPNoCheck(ExtensionType):
     oid = ExtensionOID.OCSP_NO_CHECK
 
-    def __eq__(self, other: typing.Any) -> bool:
+    def __eq__(self, other: object) -> bool:
         if not isinstance(other, OCSPNoCheck):
             return NotImplemented
 
         return True
 
-    def __ne__(self, other: typing.Any) -> bool:
-        return not self == other
-
     def __hash__(self) -> int:
         return hash(OCSPNoCheck)
 
@@ -1069,15 +1028,12 @@ class OCSPNoCheck(ExtensionType):
 class PrecertPoison(ExtensionType):
     oid = ExtensionOID.PRECERT_POISON
 
-    def __eq__(self, other: typing.Any) -> bool:
+    def __eq__(self, other: object) -> bool:
         if not isinstance(other, PrecertPoison):
             return NotImplemented
 
         return True
 
-    def __ne__(self, other: typing.Any) -> bool:
-        return not self == other
-
     def __hash__(self) -> int:
         return hash(PrecertPoison)
 
@@ -1109,15 +1065,12 @@ class TLSFeature(ExtensionType):
     def __repr__(self) -> str:
         return "<TLSFeature(features={0._features})>".format(self)
 
-    def __eq__(self, other: typing.Any) -> bool:
+    def __eq__(self, other: object) -> bool:
         if not isinstance(other, TLSFeature):
             return NotImplemented
 
         return self._features == other._features
 
-    def __ne__(self, other: typing.Any) -> bool:
-        return not self == other
-
     def __hash__(self) -> int:
         return hash(tuple(self._features))
 
@@ -1154,15 +1107,12 @@ class InhibitAnyPolicy(ExtensionType):
     def __repr__(self) -> str:
         return "<InhibitAnyPolicy(skip_certs={0.skip_certs})>".format(self)
 
-    def __eq__(self, other: typing.Any) -> bool:
+    def __eq__(self, other: object) -> bool:
         if not isinstance(other, InhibitAnyPolicy):
             return NotImplemented
 
         return self.skip_certs == other.skip_certs
 
-    def __ne__(self, other: typing.Any) -> bool:
-        return not self == other
-
     def __hash__(self) -> int:
         return hash(self.skip_certs)
 
@@ -1272,7 +1222,7 @@ class KeyUsage(ExtensionType):
             "encipher_only={1}, decipher_only={2})>"
         ).format(self, encipher_only, decipher_only)
 
-    def __eq__(self, other: typing.Any) -> bool:
+    def __eq__(self, other: object) -> bool:
         if not isinstance(other, KeyUsage):
             return NotImplemented
 
@@ -1288,9 +1238,6 @@ class KeyUsage(ExtensionType):
             and self._decipher_only == other._decipher_only
         )
 
-    def __ne__(self, other: typing.Any) -> bool:
-        return not self == other
-
     def __hash__(self) -> int:
         return hash(
             (
@@ -1320,6 +1267,10 @@ class NameConstraints(ExtensionType):
     ) -> None:
         if permitted_subtrees is not None:
             permitted_subtrees = list(permitted_subtrees)
+            if not permitted_subtrees:
+                raise ValueError(
+                    "permitted_subtrees must be a non-empty list or None"
+                )
             if not all(isinstance(x, GeneralName) for x in permitted_subtrees):
                 raise TypeError(
                     "permitted_subtrees must be a list of GeneralName objects "
@@ -1330,6 +1281,10 @@ class NameConstraints(ExtensionType):
 
         if excluded_subtrees is not None:
             excluded_subtrees = list(excluded_subtrees)
+            if not excluded_subtrees:
+                raise ValueError(
+                    "excluded_subtrees must be a non-empty list or None"
+                )
             if not all(isinstance(x, GeneralName) for x in excluded_subtrees):
                 raise TypeError(
                     "excluded_subtrees must be a list of GeneralName objects "
@@ -1347,7 +1302,7 @@ class NameConstraints(ExtensionType):
         self._permitted_subtrees = permitted_subtrees
         self._excluded_subtrees = excluded_subtrees
 
-    def __eq__(self, other: typing.Any) -> bool:
+    def __eq__(self, other: object) -> bool:
         if not isinstance(other, NameConstraints):
             return NotImplemented
 
@@ -1356,9 +1311,6 @@ class NameConstraints(ExtensionType):
             and self.permitted_subtrees == other.permitted_subtrees
         )
 
-    def __ne__(self, other: typing.Any) -> bool:
-        return not self == other
-
     def _validate_ip_name(self, tree: typing.Iterable[GeneralName]) -> None:
         if any(
             isinstance(name, IPAddress)
@@ -1445,7 +1397,7 @@ class Extension(typing.Generic[ExtensionTypeVar]):
             "value={0.value})>"
         ).format(self)
 
-    def __eq__(self, other: typing.Any) -> bool:
+    def __eq__(self, other: object) -> bool:
         if not isinstance(other, Extension):
             return NotImplemented
 
@@ -1455,14 +1407,11 @@ class Extension(typing.Generic[ExtensionTypeVar]):
             and self.value == other.value
         )
 
-    def __ne__(self, other: typing.Any) -> bool:
-        return not self == other
-
     def __hash__(self) -> int:
         return hash((self.oid, self.critical, self.value))
 
 
-class GeneralNames(object):
+class GeneralNames:
     def __init__(self, general_names: typing.Iterable[GeneralName]) -> None:
         general_names = list(general_names)
         if not all(isinstance(x, GeneralName) for x in general_names):
@@ -1541,15 +1490,12 @@ class GeneralNames(object):
     def __repr__(self) -> str:
         return "<GeneralNames({})>".format(self._general_names)
 
-    def __eq__(self, other: typing.Any) -> bool:
+    def __eq__(self, other: object) -> bool:
         if not isinstance(other, GeneralNames):
             return NotImplemented
 
         return self._general_names == other._general_names
 
-    def __ne__(self, other: typing.Any) -> bool:
-        return not self == other
-
     def __hash__(self) -> int:
         return hash(tuple(self._general_names))
 
@@ -1622,15 +1568,12 @@ class SubjectAlternativeName(ExtensionType):
     def __repr__(self) -> str:
         return "<SubjectAlternativeName({})>".format(self._general_names)
 
-    def __eq__(self, other: typing.Any) -> bool:
+    def __eq__(self, other: object) -> bool:
         if not isinstance(other, SubjectAlternativeName):
             return NotImplemented
 
         return self._general_names == other._general_names
 
-    def __ne__(self, other: typing.Any) -> bool:
-        return not self == other
-
     def __hash__(self) -> int:
         return hash(self._general_names)
 
@@ -1706,15 +1649,12 @@ class IssuerAlternativeName(ExtensionType):
     def __repr__(self) -> str:
         return "<IssuerAlternativeName({})>".format(self._general_names)
 
-    def __eq__(self, other: typing.Any) -> bool:
+    def __eq__(self, other: object) -> bool:
         if not isinstance(other, IssuerAlternativeName):
             return NotImplemented
 
         return self._general_names == other._general_names
 
-    def __ne__(self, other: typing.Any) -> bool:
-        return not self == other
-
     def __hash__(self) -> int:
         return hash(self._general_names)
 
@@ -1790,15 +1730,12 @@ class CertificateIssuer(ExtensionType):
     def __repr__(self) -> str:
         return "<CertificateIssuer({})>".format(self._general_names)
 
-    def __eq__(self, other: typing.Any) -> bool:
+    def __eq__(self, other: object) -> bool:
         if not isinstance(other, CertificateIssuer):
             return NotImplemented
 
         return self._general_names == other._general_names
 
-    def __ne__(self, other: typing.Any) -> bool:
-        return not self == other
-
     def __hash__(self) -> int:
         return hash(self._general_names)
 
@@ -1818,15 +1755,12 @@ class CRLReason(ExtensionType):
     def __repr__(self) -> str:
         return "<CRLReason(reason={})>".format(self._reason)
 
-    def __eq__(self, other: typing.Any) -> bool:
+    def __eq__(self, other: object) -> bool:
         if not isinstance(other, CRLReason):
             return NotImplemented
 
         return self.reason == other.reason
 
-    def __ne__(self, other: typing.Any) -> bool:
-        return not self == other
-
     def __hash__(self) -> int:
         return hash(self.reason)
 
@@ -1852,15 +1786,12 @@ class InvalidityDate(ExtensionType):
             self._invalidity_date
         )
 
-    def __eq__(self, other: typing.Any) -> bool:
+    def __eq__(self, other: object) -> bool:
         if not isinstance(other, InvalidityDate):
             return NotImplemented
 
         return self.invalidity_date == other.invalidity_date
 
-    def __ne__(self, other: typing.Any) -> bool:
-        return not self == other
-
     def __hash__(self) -> int:
         return hash(self.invalidity_date)
 
@@ -1904,7 +1835,7 @@ class PrecertificateSignedCertificateTimestamps(ExtensionType):
     def __hash__(self) -> int:
         return hash(tuple(self._signed_certificate_timestamps))
 
-    def __eq__(self, other: typing.Any) -> bool:
+    def __eq__(self, other: object) -> bool:
         if not isinstance(other, PrecertificateSignedCertificateTimestamps):
             return NotImplemented
 
@@ -1913,9 +1844,6 @@ class PrecertificateSignedCertificateTimestamps(ExtensionType):
             == other._signed_certificate_timestamps
         )
 
-    def __ne__(self, other: typing.Any) -> bool:
-        return not self == other
-
     def public_bytes(self) -> bytes:
         return rust_x509.encode_extension_value(self)
 
@@ -1950,7 +1878,7 @@ class SignedCertificateTimestamps(ExtensionType):
     def __hash__(self) -> int:
         return hash(tuple(self._signed_certificate_timestamps))
 
-    def __eq__(self, other: typing.Any) -> bool:
+    def __eq__(self, other: object) -> bool:
         if not isinstance(other, SignedCertificateTimestamps):
             return NotImplemented
 
@@ -1959,9 +1887,6 @@ class SignedCertificateTimestamps(ExtensionType):
             == other._signed_certificate_timestamps
         )
 
-    def __ne__(self, other: typing.Any) -> bool:
-        return not self == other
-
     def public_bytes(self) -> bytes:
         return rust_x509.encode_extension_value(self)
 
@@ -1975,15 +1900,12 @@ class OCSPNonce(ExtensionType):
 
         self._nonce = nonce
 
-    def __eq__(self, other: typing.Any) -> bool:
+    def __eq__(self, other: object) -> bool:
         if not isinstance(other, OCSPNonce):
             return NotImplemented
 
         return self.nonce == other.nonce
 
-    def __ne__(self, other: typing.Any) -> bool:
-        return not self == other
-
     def __hash__(self) -> int:
         return hash(self.nonce)
 
@@ -2096,7 +2018,7 @@ class IssuingDistributionPoint(ExtensionType):
             "{0.only_contains_attribute_certs})>".format(self)
         )
 
-    def __eq__(self, other: typing.Any) -> bool:
+    def __eq__(self, other: object) -> bool:
         if not isinstance(other, IssuingDistributionPoint):
             return NotImplemented
 
@@ -2111,9 +2033,6 @@ class IssuingDistributionPoint(ExtensionType):
             == other.only_contains_attribute_certs
         )
 
-    def __ne__(self, other: typing.Any) -> bool:
-        return not self == other
-
     def __hash__(self) -> int:
         return hash(
             (
@@ -2182,15 +2101,12 @@ class UnrecognizedExtension(ExtensionType):
             "value={0.value!r})>".format(self)
         )
 
-    def __eq__(self, other: typing.Any) -> bool:
+    def __eq__(self, other: object) -> bool:
         if not isinstance(other, UnrecognizedExtension):
             return NotImplemented
 
         return self.oid == other.oid and self.value == other.value
 
-    def __ne__(self, other: typing.Any) -> bool:
-        return not self == other
-
     def __hash__(self) -> int:
         return hash((self.oid, self.value))
 
